@@ -197,7 +197,7 @@ def generate_project(project_details: dict[str, str]) -> None:
             "extensions.json": None,
         },
         "docs": {
-            "build": {},
+            "build": {".nojekyll": None},
             "source": {
                 "_static": {},
                 "_templates": {},
@@ -207,7 +207,7 @@ def generate_project(project_details: dict[str, str]) -> None:
             "make.bat": None,
             "Makefile": None,
         },
-        "scripts": {"release.sh"},
+        "scripts": {"release.sh": None},
         "source": {
             project_name: {
                 "config": {
@@ -223,12 +223,13 @@ def generate_project(project_details: dict[str, str]) -> None:
                     "__init__.py": None,
                     "setup_logging.py": None,
                 },
+                "__init__.py": None,
                 "main.py": None,
                 "py.typed": None,
                 "VERSION": None,
             },
         },
-        "tests": {},
+        "tests": {"__init__.py": None, "test_main.py": None},
         ".gitignore": None,
         ".pre-commit-config.yaml": None,
         "CHANGELOG.md": None,
